/*
    Mosh: the mobile shell
    Copyright 2012 Keith Winstein

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef LOCALE_UTILS_HPP
#define LOCALE_UTILS_HPP

#include <string>

class LocaleVar {
 public:
  const std::string name, value;
  LocaleVar( const char *s_name, const char *s_value )
    : name( s_name ), value( s_value )
  {}
  const std::string str( void ) const;
};

const LocaleVar get_ctype( void );
const char *locale_charset( void );
bool is_utf8_locale( void );
void set_native_locale( void );
void clear_locale_variables( void );

#endif
